@@ -3,7 +3,7 @@ from __future__ import annotations
 import logging
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from better_translation.extractor import extract_from_dir
 
@@ -30,22 +30,11 @@ class StorageMessage:
     translations: Mapping[Locale, StorageTranslation]
 
     @property
-    def number_of_non_default_attributes(self) -> int:
-        number_of_non_default_attributes = 1
-
-        if self.default != self.id:
-            number_of_non_default_attributes += 1
-
-        if self.default_plural != self.default:
-            number_of_non_default_attributes += 1
-
-        if self.context:
-            number_of_non_default_attributes += 1
-
-        if self.has_plural:
-            number_of_non_default_attributes += 1
-
-        return number_of_non_default_attributes
+    def updatable_attributes(self) -> tuple[Any, ...]:
+        return (
+            self.context,
+            self.has_plural,
+        )
 
 
 @dataclass(slots=True)
